@@ -68,6 +68,9 @@ class SaturnCluster(SpecCluster):
     """
 
     # pylint: disable=unused-argument,super-init-not-called,too-many-instance-attributes
+
+    _sizes = None
+
     def __init__(
         self,
         *args,
@@ -126,6 +129,12 @@ class SaturnCluster(SpecCluster):
                 "have a different dask-saturn version on your dask cluster."
             )
 
+    def __await__(self):
+        async def _():
+            pass
+
+        return _().__await__()
+
     @classmethod
     def reset(
         cls,
@@ -164,7 +173,7 @@ class SaturnCluster(SpecCluster):
 
         response = requests.post(url, data=json.dumps(cluster_config), headers=settings.headers)
         if not response.ok:
-            raise ValueError(response.reason)
+            raise ValueError(response.json()["message"])
         return cls(**cluster_config, external_connection=external_connection)
 
     @property
@@ -226,7 +235,7 @@ class SaturnCluster(SpecCluster):
                 for pc in self.periodic_callbacks.values():
                     pc.stop()
                 raise ValueError("Cluster is not running.")
-            raise ValueError(response.reason)
+            raise ValueError(response.json()["message"])
         return response.json()
 
     # pylint: disable=invalid-overridden-method
@@ -252,6 +261,8 @@ class SaturnCluster(SpecCluster):
             url_query = "?is_external=true"
         self.cluster_url: Optional[str] = None
 
+        self._validate_sizes(worker_size, scheduler_size)
+
         cluster_config = {
             "n_workers": n_workers,
             "worker_size": worker_size,
@@ -274,7 +285,7 @@ class SaturnCluster(SpecCluster):
                 headers=self.settings.headers,
             )
             if not response.ok:
-                raise ValueError(response.reason)
+                raise ValueError(response.json()["message"])
             data = response.json()
             warnings = data.get("warnings")
             if warnings is not None:
@@ -311,7 +322,7 @@ class SaturnCluster(SpecCluster):
             url += "?is_external=true"
         response = requests.get(url, headers=self.settings.headers)
         if not response.ok:
-            raise ValueError(response.reason)
+            raise ValueError(response.json()["message"])
         return response.json()
 
     def scale(self, n: int) -> None:
@@ -323,7 +334,7 @@ class SaturnCluster(SpecCluster):
         url = urljoin(self.cluster_url, "scale")
         response = requests.post(url, json.dumps({"n": n}), headers=self.settings.headers)
         if not response.ok:
-            raise ValueError(response.reason)
+            raise ValueError(response.json()["message"])
 
     def adapt(self, minimum: int, maximum: int) -> None:
         """Adapt cluster to have between ``minimum`` and ``maximum`` workers"""
@@ -334,7 +345,7 @@ class SaturnCluster(SpecCluster):
             headers=self.settings.headers,
         )
         if not response.ok:
-            raise ValueError(response.reason)
+            raise ValueError(response.json()["message"])
 
     def close(self) -> None:
         """
@@ -343,7 +354,7 @@ class SaturnCluster(SpecCluster):
         url = urljoin(self.cluster_url, "close")
         response = requests.post(url, headers=self.settings.headers)
         if not response.ok:
-            raise ValueError(response.reason)
+            raise ValueError(response.json()["message"])
         for pc in self.periodic_callbacks.values():
             pc.stop()
 
@@ -384,6 +395,30 @@ class SaturnCluster(SpecCluster):
         if self.autoclose:
             self.close()
 
+    # pylint: disable=access-member-before-definition
+    def _validate_sizes(
+        self,
+        worker_size: Optional[str] = None,
+        scheduler_size: Optional[str] = None,
+    ):
+        """Validate the options provided"""
+        if self._sizes is None:
+            self._sizes = list_sizes(self.external)
+        errors = []
+        if worker_size is not None:
+            if worker_size not in self._sizes:
+                errors.append(
+                    f"Proposed worker_size: {worker_size} is not a valid option. "
+                    f"Options are: {self._sizes}."
+                )
+            if scheduler_size not in self._sizes:
+                errors.append(
+                    f"Proposed scheduler_size: {scheduler_size} is not a valid option. "
+                    f"Options are: {self._sizes}."
+                )
+        if len(errors) > 0:
+            raise ValueError(" ".join(errors))
+
 
 def _options(external_connection: Optional[ExternalConnection] = None) -> Dict[str, Any]:
     if external_connection is None:
@@ -393,7 +428,7 @@ def _options(external_connection: Optional[ExternalConnection] = None) -> Dict[s
     url = urljoin(settings.url, "api/dask_clusters/info")
     response = requests.get(url, headers=settings.headers)
     if not response.ok:
-        raise ValueError(response.reason)
+        raise ValueError(response.json()["message"])
     return response.json()["server_options"]
 
 
